Woman’s Parents Accepting Of Mixed-Attractiveness Relationship | The Onion - America's Finest News Source
Description: CHICAGO—Admitting it took them some time to come around to the idea, the parents of local woman Laura Stevens said Wednesday that they had finally accepted their daughter’s mixed-attractiveness relationship with Kyle Baker, a man who is consid...
Keywords: parents,dating,lifestyle

- Video
- Politics
- Sports
- Business
- Science/Tech
- Entertainment
- Breaking

# Woman’s Parents Accepting Of Mixed-Attractiveness Relationship

News in Brief • parents • dating • Lifestyle • ISSUE 51•02 • Jan 14, 2015

CHICAGO—Admitting it took them some time to come around to the idea, the parents of local woman Laura Stevens said Wednesday that they had finally accepted their daughter’s mixed-attractiveness relationship with Kyle Baker, a man who is considerably worse-looking than she is. “To be honest, we were quite surprised when Laura brought Kyle to the house for the first time, but eventually we came around to it,” said Stevens’ mother, Janet, who noted that the pair were still met with uncomfortable stares and disapproval from other family members—especially Laura’s grandmother—at last year’s Thanksgiving dinner. “Her father was particularly upset at first, but now I think he’s learned to accept it, and he’s even grown to like Kyle. Besides, Kyle seems to make Laura happy, and that’s all that really matters.” Janet Stevens went on to say that, if the two ever got married, she would love their children no matter how average-looking they are.

# Popular Onion Video

Watch more videos

#### Recent News

Scout Returns With News Of Quicker Checkout Line To The East Area Dad Didn’t Shell Out $100 At Aquarium For Lecture About Ecosystem Report: Only 2% Of Internet Worth Sitting Through 15-Second Ad Woman’s Parents Accepting Of Mixed-Attractiveness Relationship U.S. Government Offers 100 Million Americans Generous Severance Deal To Leave Country